from enum import IntEnum


class Network(IntEnum):
    MAINNET = 1
    ROPSTEN = 3
    RINKEBY = 4
    GOERLI = 5
    POLYGON = 137
    BSC = 56
    AVALANCHE = 43114
    ARBITRUM = 42161
    OPTIMISM = 10
    FANTOM = 250
